# Changelog

## 0.2.x

### 0.2.1 (2020 July 01)

- Add `setup.py` and package for pypi release.

### 0.2.0 (2020 June 22)

#### Enhancements

- Rewrite random number generation to use numpy's newer Generator approach.

#### Bugfixes

- Fix bug in bootstrapping that would cause final entry in list to be skipped.

## 0.1.x

### 0.1.0 (2020 June 18)

Initial Release
